import{b as e,c as o,n as s,s as i,x as t}from"./index-D2ez82lt.js";import"./c.Cf021qfJ.js";import"./c.poAaLtz1.js";let a=class extends i{render(){return t`
      <esphome-process-dialog
        .heading=${`Clean MQTT discovery topics for ${this.configuration}`}
        .type=${"clean-mqtt"}
        .spawnParams=${{configuration:this.configuration}}
        @closed=${this._handleClose}
      >
      </esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};e([o()],a.prototype,"configuration",void 0),a=e([s("esphome-clean-mqtt-dialog")],a);
//# sourceMappingURL=c.DRb9x_iG.js.map
